# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later
"""AlexNet_, to be trained from scratch.

This configuration contains a version of AlexNet_ (c.f. `TorchVision's
page <alexnet-pytorch_>`_), modified for a variable number of outputs
(defaults to 1).
"""

import torchvision.transforms
from mednet.libs.classification.models.alexnet import Alexnet
from mednet.libs.common.models.transforms import RGB, SquareCenterPad
from torch.nn import BCEWithLogitsLoss
from torch.optim import SGD

model = Alexnet(
    loss_type=BCEWithLogitsLoss,
    optimizer_type=SGD,
    optimizer_arguments=dict(lr=0.01, momentum=0.1),
    pretrained=False,
    model_transforms=[
        SquareCenterPad(),
        torchvision.transforms.Resize(512, antialias=True),
        RGB(),
    ],
    augmentation_transforms=[],
)
