# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later
"""DenseNet_, to be fine-tuned. Pre-trained on ImageNet_.

This configuration contains a version of DenseNet_ (c.f. `TorchVision's
page <alexnet_pytorch_>`), modified for a variable number of outputs
(defaults to 1).

N.B.: The output layer is **always** initialized from scratch.
"""

import torchvision.transforms
from mednet.libs.classification.models.densenet import Densenet
from mednet.libs.common.models.transforms import RGB, SquareCenterPad
from torch.nn import BCEWithLogitsLoss
from torch.optim import Adam

model = Densenet(
    loss_type=BCEWithLogitsLoss,
    optimizer_type=Adam,
    optimizer_arguments=dict(lr=0.0001),
    pretrained=True,
    dropout=0.1,
    model_transforms=[
        SquareCenterPad(),
        torchvision.transforms.Resize(
            512,
            antialias=True,
            interpolation=torchvision.transforms.InterpolationMode.BILINEAR,
        ),
        RGB(),
    ],
    augmentation_transforms=[],
)
