# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later
"""Simple CNN for Tuberculosis Detection, to be trained from scratch.

Implementation of the model architecture proposed by F. Pasa in the article
"Efficient Deep Network Architectures for Fast Chest X-Ray Tuberculosis
Screening and Visualization".

Reference: [PASA-2019]_
"""

import torchvision.transforms
from mednet.libs.classification.models.pasa import Pasa
from mednet.libs.common.models.transforms import Grayscale, SquareCenterPad
from torch.nn import BCEWithLogitsLoss
from torch.optim import Adam

model = Pasa(
    loss_type=BCEWithLogitsLoss,
    optimizer_type=Adam,
    optimizer_arguments=dict(lr=8e-5),
    model_transforms=[
        Grayscale(),
        SquareCenterPad(),
        torchvision.transforms.Resize(
            512,
            antialias=True,
            interpolation=torchvision.transforms.InterpolationMode.BILINEAR,
        ),
    ],
    augmentation_transforms=[],
)
