import typing

from mednet.libs.common.data.typing import RawDataLoader, Sample


class ClassificationRawDataLoader(RawDataLoader):
    """A loader object can load samples and labels from storage for classification tasks."""

    def __init__(self):
        super().__init__()

    def sample(self, _: tuple[str, int, typing.Any | None]) -> Sample:
        """Load whole samples from media.

        Parameters
        ----------
         _
            Information about the sample to load. Implementation dependent.
        """

        raise NotImplementedError("You must implement the `sample()` method")

    def label(self, k: typing.Any) -> int | list[int]:
        """Load only sample label from media.

        If you do not override this implementation, then, by default,
        this method will call :py:meth:`sample` to load the whole sample
        and extract the label.

        Parameters
        ----------
        k
            The sample to load. This is implementation-dependent.

        Returns
        -------
        int | list[int]
            The label corresponding to the specified sample.
        """

        return self.sample(k)[1]["target"]
