# Copyright © 2022 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later

import importlib

import click
from clapper.click import AliasedGroup


@click.group(
    cls=AliasedGroup,
    context_settings=dict(help_option_names=["-?", "-h", "--help"]),
)
def classification():
    """Image classification benchmark."""
    pass


classification.add_command(importlib.import_module("..config", package=__name__).config)
classification.add_command(
    importlib.import_module("..database", package=__name__).database,
)
classification.add_command(
    importlib.import_module("..predict", package=__name__).predict
)
classification.add_command(importlib.import_module("..train", package=__name__).train)
classification.add_command(
    importlib.import_module(
        "mednet.libs.common.scripts.train_analysis",
        package=__name__,
    ).train_analysis,
)
classification.add_command(
    importlib.import_module("..evaluate", package=__name__).evaluate,
)
classification.add_command(
    importlib.import_module("..experiment", package=__name__).experiment,
)
classification.add_command(
    importlib.import_module("..upload", package=__name__).upload,
)


@click.group(
    cls=AliasedGroup,
    context_settings=dict(help_option_names=["-?", "-h", "--help"]),
)
def saliency():
    """Generate, evaluate and view saliency maps."""
    pass


classification.add_command(saliency)

saliency.add_command(
    importlib.import_module("..saliency.generate", package=__name__).generate,
)
saliency.add_command(
    importlib.import_module(
        "..saliency.completeness",
        package=__name__,
    ).completeness,
)
saliency.add_command(
    importlib.import_module(
        "..saliency.interpretability",
        package=__name__,
    ).interpretability,
)
saliency.add_command(
    importlib.import_module("..saliency.evaluate", package=__name__).evaluate,
)
saliency.add_command(
    importlib.import_module("..saliency.view", package=__name__).view,
)
