# SPDX-FileCopyrightText: Copyright © 2024 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""DRIU Network for Vessel Segmentation.

Deep Retinal Image Understanding (DRIU), a unified framework of retinal image
analysis that provides both retinal vessel and optic disc segmentation using
deep Convolutional Neural Networks (CNNs).

Reference: [MANINIS-2016]_
"""

from mednet.libs.common.models.transforms import ResizeMaxSide, SquareCenterPad
from mednet.libs.segmentation.engine.adabound import AdaBound
from mednet.libs.segmentation.models.driu import DRIU
from mednet.libs.segmentation.models.losses import SoftJaccardBCELogitsLoss

lr = 0.001
alpha = 0.7
betas = (0.9, 0.999)
eps = 1e-08
weight_decay = 0
final_lr = 0.1
gamma = 1e-3
eps = 1e-8
amsbound = False

resize_transform = ResizeMaxSide(512)

model = DRIU(
    loss_type=SoftJaccardBCELogitsLoss,
    loss_arguments=dict(alpha=alpha),
    optimizer_type=AdaBound,
    optimizer_arguments=dict(
        lr=lr,
        betas=betas,
        final_lr=final_lr,
        gamma=gamma,
        eps=eps,
        weight_decay=weight_decay,
        amsbound=amsbound,
    ),
    model_transforms=[
        resize_transform,
        SquareCenterPad(),
    ],
    augmentation_transforms=[],
)
