# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later

import importlib

import click
from clapper.click import AliasedGroup

from . import (
    # analyze,
    config,
    database,
    evaluate,
    predict,
    train,
    view,
)


@click.group(
    cls=AliasedGroup,
    context_settings=dict(help_option_names=["-?", "-h", "--help"]),
)
def segmentation():
    """Binary Segmentation Benchmark."""
    pass


# segmentation.add_command(analyze.analyze)
segmentation.add_command(config.config)
segmentation.add_command(database.database)
segmentation.add_command(train.train)
segmentation.add_command(predict.predict)
segmentation.add_command(evaluate.evaluate)
segmentation.add_command(
    importlib.import_module(
        "mednet.libs.common.scripts.train_analysis",
        package=__name__,
    ).train_analysis,
)
segmentation.add_command(view.view)
segmentation.add_command(
    importlib.import_module("..experiment", package=__name__).experiment,
)
